@@ -333,26 +333,27 @@ test_that("calculate_diff_abundance works", {
 
 test_that("correct_lip_for_abundance works", {
   data <- rapamycin_10uM
-  diff_lip = data %>%
-      dplyr::mutate(fg_intensity_log2 = log2(fg_quantity)) %>%
-      assign_missingness(
-        sample = r_file_name,
-        condition = r_condition,
-        intensity = fg_intensity_log2,
-        grouping = eg_precursor_id,
-        ref_condition = "control",
-        retain_columns = "pg_protein_accessions") %>%
-      calculate_diff_abundance(
-        sample = r_file_name,
-        condition = r_condition,
-        grouping = eg_precursor_id,
-        intensity_log2 = fg_intensity_log2,
-        comparison = comparison,
-        method = "t-test",
-        retain_columns = "pg_protein_accessions"
-       )
+  diff_lip <- data %>%
+    dplyr::mutate(fg_intensity_log2 = log2(fg_quantity)) %>%
+    assign_missingness(
+      sample = r_file_name,
+      condition = r_condition,
+      intensity = fg_intensity_log2,
+      grouping = eg_precursor_id,
+      ref_condition = "control",
+      retain_columns = "pg_protein_accessions"
+    ) %>%
+    calculate_diff_abundance(
+      sample = r_file_name,
+      condition = r_condition,
+      grouping = eg_precursor_id,
+      intensity_log2 = fg_intensity_log2,
+      comparison = comparison,
+      method = "t-test",
+      retain_columns = "pg_protein_accessions"
+    )
 
-  diff_trp = data %>%
+  diff_trp <- data %>%
     dplyr::group_by(pg_protein_accessions, r_file_name) %>%
     dplyr::mutate(pg_quantity = sum(fg_quantity)) %>%
     dplyr::distinct(
@@ -366,16 +367,19 @@ test_that("correct_lip_for_abundance works", {
       sample = r_file_name,
       condition = r_condition,
       intensity = pg_intensity_log2,
-                     grouping = pg_protein_accessions,
-                     ref_condition = "control") %>%
-    calculate_diff_abundance(sample = r_file_name,
-                     condition = r_condition,
-                     grouping = pg_protein_accessions,
-                     intensity_log2 = pg_intensity_log2,
-                     comparison = comparison,
-                     method = "t-test")
+      grouping = pg_protein_accessions,
+      ref_condition = "control"
+    ) %>%
+    calculate_diff_abundance(
+      sample = r_file_name,
+      condition = r_condition,
+      grouping = pg_protein_accessions,
+      intensity_log2 = pg_intensity_log2,
+      comparison = comparison,
+      method = "t-test"
+    )
 
-  corrected_satterthwaite = correct_lip_for_abundance(
+  corrected_satterthwaite <- correct_lip_for_abundance(
     lip_data = diff_lip,
     trp_data = diff_trp,
     protein_id = pg_protein_accessions,
@@ -384,7 +388,7 @@ test_that("correct_lip_for_abundance works", {
     method = "satterthwaite"
   )
 
-  corrected_no_df_approximation = correct_lip_for_abundance(
+  corrected_no_df_approximation <- correct_lip_for_abundance(
     lip_data = diff_lip,
     trp_data = diff_trp,
     protein_id = pg_protein_accessions,
@@ -394,14 +398,14 @@ test_that("correct_lip_for_abundance works", {
   )
 
   expect_is(corrected_satterthwaite, "data.frame")
-  expect_equal(corrected_satterthwaite$adj_diff[1], 2.474938, tolerance=1e-3)
-  expect_equal(corrected_satterthwaite$adj_std_error[1], 0.1531189, tolerance=1e-3)
-  expect_equal(corrected_satterthwaite$adj_pval[1], 1.561211e-05, tolerance=1e-3)
-  expect_equal(corrected_satterthwaite$df[1], 10.13124, tolerance=1e-3)
+  expect_equal(corrected_satterthwaite$adj_diff[1], 2.474938, tolerance = 1e-3)
+  expect_equal(corrected_satterthwaite$adj_std_error[1], 0.1531189, tolerance = 1e-3)
+  expect_equal(corrected_satterthwaite$adj_pval[1], 1.561211e-05, tolerance = 1e-3)
+  expect_equal(corrected_satterthwaite$df[1], 10.13124, tolerance = 1e-3)
 
   expect_is(corrected_no_df_approximation, "data.frame")
-  expect_equal(corrected_no_df_approximation$adj_diff[1], 2.474938, tolerance=1e-3)
-  expect_equal(corrected_no_df_approximation$adj_std_error[1], 0.1531189, tolerance=1e-3)
+  expect_equal(corrected_no_df_approximation$adj_diff[1], 2.474938, tolerance = 1e-3)
+  expect_equal(corrected_no_df_approximation$adj_std_error[1], 0.1531189, tolerance = 1e-3)
   expect_equal(corrected_no_df_approximation$df[1], 6)
 })
 
@@ -643,6 +647,8 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
     grouping = peptide,
     response = normalised_intensity_log2,
     dose = concentration,
+    n_replicate_completeness = 2,
+    n_condition_completeness = 4,
     log_logarithmic = TRUE,
     retain_columns = c(protein)
   )
@@ -650,7 +656,7 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
   test_that("fit_drc_4p works", {
     # did not test the argument include_models = TRUE
     expect_is(drc_fit, "data.frame")
-    expect_equal(nrow(drc_fit), 282)
+    expect_equal(nrow(drc_fit), 306)
     expect_equal(ncol(drc_fit), 18)
     expect_equal(round(max(drc_fit$correlation, na.rm = TRUE), digits = 3), 0.876)
     expect_equal(round(min(drc_fit$anova_pval, na.rm = TRUE), digits = 6), 0.007297)
@@ -671,7 +677,7 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
       ))
     })
 
-    expect_is(p, "ggplot")
+    expect_is(p, "list")
     expect_warning(print(p), NA)
 
     rlang::with_options(lifecycle_verbosity = "warning", {
@@ -701,7 +707,7 @@ if (Sys.getenv("TEST_PROTTI") == "true") {
       y_axis_name = "test y-Axis"
     )
 
-    expect_is(p, "ggplot")
+    expect_is(p, "list")
     expect_warning(print(p), NA)
 
     p_facet <- drc_4p_plot(
